#include <bindings.dsl.h>
#include <gts.h>

-- | GTS types appear together in the same module because of circular dependencies.

module Bindings.Gts.Types where
import Bindings.GLib
#strict_import

-- | <http://gts.sourceforge.net/reference/gts-binary-heaps.html#GTSHEAP>

#opaque_t GtsHeap

-- | <http://gts.sourceforge.net/reference/gts-extended-binary-heaps.html#GTSEHEAPPAIR>

#starttype GtsEHeapPair
#field data , <gpointer>
#field key , <gdouble>
#field pos , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-extended-binary-heaps.html#GTSKEYFUNC>

#callback GtsKeyFunc , <gpointer> -> <gpointer> -> IO <gdouble>

-- | <http://gts.sourceforge.net/reference/gts-extended-binary-heaps.html#GTSEHEAP>

#opaque_t GtsEHeap

-- | <http://gts.sourceforge.net/reference/gts-first-in-first-out-heaps.html#GTSFIFO>

#opaque_t GtsFifo

-- | <http://gts.sourceforge.net/reference/gts-vectors-and-matrices.html#GTSMATRIX>

#opaque_t GtsMatrix
#synonym_t GtsVector , Ptr <gdouble>
#synonym_t GtsVector4 , Ptr <gdouble>

-- | <http://gts.sourceforge.net/reference/gts-simple-statistics.html#GTSRANGE>

#starttype GtsRange
#field min , <gdouble>
#field max , <gdouble>
#field sum , <gdouble>
#field sum2 , <gdouble>
#field mean , <gdouble>
#field stddev , <gdouble>
#field n , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-miscellaneous-macros-and-functions.html#GTSFILE>

#starttype GtsFile
#field fp , Ptr CFile
#field s , Ptr <gchar>
#field s1 , Ptr <gchar>
#field line , <guint>
#field pos , <guint>
#field token , Ptr <GString>
#field type , <GtsTokenType>
#field error , Ptr <gchar>
#field curline , <guint>
#field curpos , <guint>
#field scope , <guint>
#field scope_max , <guint>
#field next_token , <gint>
#field delimiters , Ptr <gchar>
#field comments , Ptr <gchar>
#field tokens , Ptr <gchar>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-miscellaneous-macros-and-functions.html#GTSTOKENTYPE>

#integral_t GtsTokenType
#num GTS_NONE
#num GTS_INT
#num GTS_UINT
#num GTS_FLOAT
#num GTS_DOUBLE
#num GTS_STRING
#num GTS_FILE
#num GTS_ERROR

-- | <http://gts.sourceforge.net/reference/gts-miscellaneous-macros-and-functions.html#GTSFILEVARIABLE>

#starttype GtsFileVariable
#field type , <GtsTokenType>
#array_field name , <gchar>
#field unique , <gboolean>
#field data , <gpointer>
#field set , <gboolean>
#field line , <guint>
#field pos , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-object-class.html#GTSOBJECTCLASS>

#starttype GtsObjectClass
#field info , <GtsObjectClassInfo>
#field parent_class , Ptr <GtsObjectClass>
#field clone , FunPtr (Ptr <GtsObject> -> Ptr <GtsObject>  -> IO ())
#field destroy , FunPtr (Ptr <GtsObject>  -> IO ())
#field read , FunPtr (Ptr (Ptr <GtsObject>) -> Ptr <GtsFile>  -> IO ())
#field write , FunPtr (Ptr <GtsObject> -> Ptr CFile -> IO ())
#field color , FunPtr (Ptr <GtsObject>  -> IO <GtsColor>)
#field attributes , FunPtr (Ptr <GtsObject> -> Ptr <GtsObject>  -> IO ())
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-object-class.html#GTSOBJECT>

#starttype GtsObject
#field klass , Ptr <GtsObjectClass>
#field reserved , <gpointer>
#field flags , <guint32>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-object-class.html#GTSOBJECTCLASSINFO>

#starttype GtsObjectClassInfo
#array_field name , <gchar>
#field object_size , <guint>
#field class_size , <guint>
#field class_init_func , <GtsObjectClassInitFunc>
#field object_init_func , <GtsObjectInitFunc>
#field arg_set_func , <GtsArgSetFunc>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-object-class.html#GTSOBJECTCLASSINITFUNC>

#callback GtsObjectClassInitFunc , Ptr <GtsObjectClass> -> IO ()

-- | <http://gts.sourceforge.net/reference/gts-object-class.html#GTSOBJECTINITFUNC>

#callback GtsObjectInitFunc , Ptr <GtsObject> -> IO ()

-- | <http://gts.sourceforge.net/reference/gts-object-class.html#GTSARGSETFUNC>

#callback GtsArgSetFunc , Ptr <GtsObject> -> IO ()

-- | <http://gts.sourceforge.net/reference/gts-object-class.html#GTSARGGETFUNC>

#callback GtsArgGetFunc , Ptr <GtsObject> -> IO ()

-- | <http://gts.sourceforge.net/reference/gts-object-class.html#GTSOBJECTFLAGS>

#integral_t GtsObjectFlags
#num GTS_DESTROYED
#num GTS_USER_FLAG

-- | <http://gts.sourceforge.net/reference/gts-object-class.html#GTSCOLOR>

#starttype GtsColor
#field r , <gfloat>
#field g , <gfloat>
#field b , <gfloat>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-container-classes.html#GTSCONTAINERCLASS>

#starttype GtsContainerClass
#field parent_class , <GtsSListContaineeClass>
#field add , FunPtr (Ptr <GtsContainer> -> Ptr <GtsContainee>  -> IO ())
#field remove , FunPtr (Ptr <GtsContainer> -> Ptr <GtsContainee>  -> IO ())
#field foreach , FunPtr (Ptr <GtsContainer> -> <GtsFunc> -> <gpointer> -> IO ())
#field size , FunPtr (Ptr <GtsContainer>  -> IO <guint>)
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-container-classes.html#GTSCONTAINER>

#starttype GtsContainer
#field object , <GtsSListContainee>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-container-classes.html#GTSHASHCONTAINERCLASS>

#starttype GtsHashContainerClass
#field parent_class , <GtsContainerClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-container-classes.html#GTSHASHCONTAINER>

#starttype GtsHashContainer
#field c , <GtsContainer>
#field items , Ptr <GHashTable>
#field frozen , <gboolean>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-container-classes.html#GTSSLISTCONTAINERCLASS>

#starttype GtsSListContainerClass
#field parent_class , <GtsContainerClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-container-classes.html#GTSSLISTCONTAINER>

#starttype GtsSListContainer
#field c , <GtsContainer>
#field items , Ptr <GSList>
#field frozen , <gboolean>
#stoptype


-- | <http://gts.sourceforge.net/reference/gts-containee-classes.html#GTSCONTAINEECLASS>

#starttype GtsContaineeClass
#field parent_class , <GtsObjectClass>
#field add_container , FunPtr (Ptr <GtsContainee> -> Ptr <GtsContainer>  -> IO ())
#field remove_container , FunPtr (Ptr <GtsContainee> -> Ptr <GtsContainer>  -> IO ())
#field foreach , FunPtr (Ptr <GtsContainee> -> <GtsFunc> -> <gpointer> -> IO ())
#field is_contained , FunPtr (Ptr <GtsContainee> -> Ptr <GtsContainer>  -> IO <gboolean>)
#field replace , FunPtr (Ptr <GtsContainee> -> Ptr <GtsContainee>  -> IO ())
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-containee-classes.html#GTSCONTAINEE>

#starttype GtsContainee
#field object , <GtsObject>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-containee-classes.html#GTSSLISTCONTAINEECLASS>

#starttype GtsSListContaineeClass
#field parent_class , <GtsContaineeClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-containee-classes.html#GTSSLISTCONTAINEE>

#starttype GtsSListContainee
#field containee , <GtsContainee>
#field containers , Ptr <GSList>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-points.html#GTSPOINTCLASS>

#starttype GtsPointClass
#field parent_class , <GtsObjectClass>
#field binary , <gboolean>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-points.html#GTSPOINT>

#starttype GtsPoint
#field object , <GtsObject>
#field x , <gdouble>
#field y , <gdouble>
#field z , <gdouble>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-points.html#GTSINTERSECT>

#integral_t GtsIntersect
#num GTS_OUT
#num GTS_ON
#num GTS_IN

-- | <http://gts.sourceforge.net/reference/gts-vertices.html#GTSVERTEXCLASS>

#starttype GtsVertexClass
#field parent_class , <GtsPointClass>
#field intersection_attributes , FunPtr (Ptr <GtsVertex> -> Ptr <GtsObject> -> Ptr <GtsObject>  -> IO ())
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-vertices.html#GTSVERTEX>

#starttype GtsVertex
#field p , <GtsPoint>
#field segments , Ptr <GSList>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-segments.html#GTSSEGMENTCLASS>

#starttype GtsSegmentClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-segments.html#GTSSEGMENT>

#starttype GtsSegment
#field object , <GtsObject>
#field v1 , Ptr <GtsVertex>
#field v2 , Ptr <GtsVertex>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-edges.html#GTSEDGECLASS>

#starttype GtsEdgeClass
#field parent_class , <GtsSegmentClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-edges.html#GTSEDGE>

#starttype GtsEdge
#field segment , <GtsSegment>
#field triangles , Ptr <GSList>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-edges.html#GTSENCROACHFUNC>

#callback GtsEncroachFunc , Ptr <GtsVertex> -> Ptr <GtsEdge> -> Ptr <GtsSurface> -> <gpointer> -> IO <gboolean>

-- | <http://gts.sourceforge.net/reference/gts-triangles.html#GTSTRIANGLECLASS>

#starttype GtsTriangleClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-triangles.html#GTSTRIANGLE>

#starttype GtsTriangle
#field object , <GtsObject>
#field e1 , Ptr <GtsEdge>
#field e2 , Ptr <GtsEdge>
#field e3 , Ptr <GtsEdge>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-faces.html#GTSFACECLASS>

#starttype GtsFaceClass
#field parent_class , <GtsTriangleClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-faces.html#GTSFACE>

#starttype GtsFace
#field triangle , <GtsTriangle>
#field surfaces , Ptr <GSList>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-surfaces.html#GTSSURFACECLASS>

#starttype GtsSurfaceClass
#field parent_class , <GtsObjectClass>
#field add_face , FunPtr (Ptr <GtsSurface> -> Ptr <GtsFace>  -> IO ())
#field remove_face , FunPtr (Ptr <GtsSurface> -> Ptr <GtsFace>  -> IO ())
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-surfaces.html#GTSSURFACE>

#opaque_t GtsSurface

-- | <http://gts.sourceforge.net/reference/gts-surfaces.html#GTSSURFACESTATS>

#starttype GtsSurfaceStats
#field n_faces , <guint>
#field n_incompatible_faces , <guint>
#field n_duplicate_faces , <guint>
#field n_boundary_edges , <guint>
#field n_non_manifold_edges , <guint>
#field edges_per_vertex , <GtsRange>
#field faces_per_edge , <GtsRange>
#field parent , Ptr <GtsSurface>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-surfaces.html#GTSSURFACEQUALITYSTATS>

#starttype GtsSurfaceQualityStats
#field face_quality , <GtsRange>
#field face_area , <GtsRange>
#field edge_length , <GtsRange>
#field edge_angle , <GtsRange>
#field parent , Ptr <GtsSurface>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-surfaces.html#GTSFUNC>

#callback GtsFunc , <gpointer> -> <gpointer> -> IO <gint>

-- | <http://gts.sourceforge.net/reference/gts-surfaces.html#GTSSURFACETRAVERSE>

#opaque_t GtsSurfaceTraverse

-- | <http://gts.sourceforge.net/reference/gts-bounding-boxes-trees.html#GTSBBOXCLASS>

#starttype GtsBBoxClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-bounding-boxes-trees.html#GTSBBOX>

#starttype GtsBBox
#field object , <GtsObject>
#field bounded , <gpointer>
#field x1 , <gdouble>
#field y1 , <gdouble>
#field z1 , <gdouble>
#field x2 , <gdouble>
#field y2 , <gdouble>
#field z2 , <gdouble>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-bounding-boxes-trees.html#GTSBBTREETRAVERSEFUNC>

#callback GtsBBTreeTraverseFunc , Ptr <GtsBBox> -> Ptr <GtsBBox> -> <gpointer> -> IO ()

-- | <http://gts.sourceforge.net/reference/gts-bounding-boxes-trees.html#GTSBBOXDISTFUNC>

#callback GtsBBoxDistFunc , Ptr <GtsPoint> -> <gpointer> -> IO <gdouble>

-- | <http://gts.sourceforge.net/reference/gts-bounding-boxes-trees.html#GTSBBOXCLOSESTFUNC>

#callback GtsBBoxClosestFunc , Ptr <GtsPoint> -> <gpointer> -> IO (Ptr <GtsPoint>)

-- | <http://gts.sourceforge.net/reference/gts-boolean-operations.html#GTSSURFACEINTERCLASS>

#starttype GtsSurfaceInterClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-boolean-operations.html#GTSSURFACEINTER>

#starttype GtsSurfaceInter
#field object , <GtsObject>
#field s1 , Ptr <GtsSurface>
#field s2 , Ptr <GtsSurface>
#field edges , Ptr <GSList>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-boolean-operations.html#GTSBOOLEANOPERATION>

#integral_t GtsBooleanOperation
#num GTS_1_OUT_2
#num GTS_1_IN_2
#num GTS_2_OUT_1
#num GTS_2_IN_1

-- | <http://gts.sourceforge.net/reference/gts-surface-simplification-and-refinement.html#GTSCOARSENFUNC>

#callback GtsCoarsenFunc , Ptr <GtsEdge> -> Ptr <GtsVertexClass> -> <gpointer> -> IO (Ptr <GtsVertex>)

-- | <http://gts.sourceforge.net/reference/gts-surface-simplification-and-refinement.html#GTSREFINEFUNC>

#callback GtsRefineFunc , Ptr <GtsEdge> -> Ptr <GtsVertexClass> -> <gpointer> -> IO (Ptr <GtsVertex>)

-- | <http://gts.sourceforge.net/reference/gts-surface-simplification-and-refinement.html#GTSSTOPFUNC>

#callback GtsStopFunc , <gdouble> -> <guint> -> <gpointer> -> IO <gboolean>

-- | <http://gts.sourceforge.net/reference/gts-surface-simplification-and-refinement.html#GTSVOLUMEOPTIMIZEDPARAMS>

#starttype GtsVolumeOptimizedParams
#field volume_weight , <gdouble>
#field boundary_weight , <gdouble>
#field shape_weight , <gdouble>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-out-of-core-simplification.html#GTSCLUSTERCLASS>

#starttype GtsClusterClass
#field parent_class , <GtsObjectClass>
#field add , FunPtr (Ptr <GtsCluster> -> Ptr <GtsPoint> -> <gpointer> -> IO ())
#field update , FunPtr (Ptr <GtsCluster> -> IO ())
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-out-of-core-simplification.html#GTSCLUSTER>

#starttype GtsCluster
#field parent , <GtsObject>
#field id , <GtsClusterId>
#field v , Ptr <GtsVertex>
#field n , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-out-of-core-simplification.html#GTSCLUSTERID>

#starttype GtsClusterId
#field x , <guint>
#field y , <guint>
#field z , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-out-of-core-simplification.html#GTSCLUSTERGRIDCLASS>

#starttype GtsClusterGridClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-out-of-core-simplification.html#GTSCLUSTERGRID>

#starttype GtsClusterGrid
#field parent , <GtsObject>
#field surface , Ptr <GtsSurface>
#field bbox , Ptr <GtsBBox>
#field size , <GtsVector>
#field cluster_class , Ptr <GtsClusterClass>
#field clusters , Ptr <GHashTable>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-isosurfaces-from-3d-functions.html#GTSCARTESIANGRID>

#starttype GtsCartesianGrid
#field nx , <guint>
#field ny , <guint>
#field nz , <guint>
#field x , <gdouble>
#field dx , <gdouble>
#field y , <gdouble>
#field dy , <gdouble>
#field z , <gdouble>
#field dz , <gdouble>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-isosurfaces-from-3d-functions.html#GTSGRIDPLANE>

#starttype GtsGridPlane
#field p , Ptr (Ptr <GtsPoint>)
#field nx , <guint>
#field ny , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-isosurfaces-from-3d-functions.html#GTSISOSLICE>

#opaque_t GtsIsoSlice

-- | <http://gts.sourceforge.net/reference/gts-delaunay-and-constrained-delaunay-triangulations.html#GTSCONSTRAINTCLASS>

#opaque_t GtsConstraintClass

-- | <http://gts.sourceforge.net/reference/gts-delaunay-and-constrained-delaunay-triangulations.html#GTSCONSTRAINT>

#opaque_t GtsConstraint

-- | <http://gts.sourceforge.net/reference/gts-vertex-split.html#GTSSPLITCLASS>

#starttype GtsSplitClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-vertex-split.html#GTSSPLITCFACE>

#opaque_t GtsSplitCFace

-- | <http://gts.sourceforge.net/reference/gts-vertex-split.html#GTSSPLIT>

#starttype GtsSplit
#field object , <GtsObject>
#field v , Ptr <GtsVertex>
#field v1 , Ptr <GtsObject>
#field v2 , Ptr <GtsObject>
#field cfaces , Ptr <GtsSplitCFace>
#field ncf , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-vertex-split.html#GTSSPLITTRAVERSEFUNC>

#callback GtsSplitTraverseFunc , Ptr <GtsSplit> -> <gpointer> -> IO <gboolean>

-- | <http://gts.sourceforge.net/reference/gts-progressive-surfaces.html#GTSPSURFACECLASS>

#starttype GtsPSurfaceClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-progressive-surfaces.html#GTSPSURFACE>

#starttype GtsPSurface
#field object , <GtsObject>
#field s , Ptr <GtsSurface>
#field split , Ptr <GPtrArray>
#field split_class , Ptr <GtsSplitClass>
#field pos , <guint>
#field min , <guint>
#field vertices , Ptr <GPtrArray>
#field faces , Ptr <GPtrArray>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-hierarchical-vertex-split.html#GTSHSPLITCLASS>

#starttype GtsHSplitClass
#field parent_class , <GtsSplitClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-hierarchical-vertex-split.html#GTSHSPLIT>

#starttype GtsHSplit
#field split , <GtsSplit>
#field index , Ptr <GtsEHeapPair>
#field parent , Ptr <GtsHSplit>
#field nchild , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-hierarchical-surfaces.html#GTSHSURFACECLASS>

#starttype GtsHSurfaceClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-hierarchical-surfaces.html#GTSHSURFACE>

#starttype GtsHSurface
#field object , <GtsObject>
#field s , Ptr <GtsSurface>
#field roots , Ptr <GSList>
#field expandable , Ptr <GtsEHeap>
#field collapsable , Ptr <GtsEHeap>
#field split , Ptr <GPtrArray>
#field nvertex , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSGNODECLASS>

#starttype GtsGNodeClass
#field parent_class , <GtsSListContainerClass>
#field weight , FunPtr (Ptr <GtsGNode>  -> IO <gfloat>)
#field write , FunPtr (Ptr <GtsGNode> -> Ptr CFile -> IO ())
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSGNODE>

#starttype GtsGNode
#field container , <GtsSListContainer>
#field level , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSGEDGECLASS>

#starttype GtsGEdgeClass
#field parent_class , <GtsContaineeClass>
#field link , FunPtr (Ptr <GtsGEdge> -> Ptr <GtsGNode> -> Ptr <GtsGNode> -> IO (Ptr <GtsGEdge>))
#field weight , FunPtr (Ptr <GtsGEdge> -> IO <gfloat>)
#field write , FunPtr (Ptr <GtsGEdge> -> Ptr CFile -> IO ())
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSGEDGE>

#starttype GtsGEdge
#field containee , <GtsContainee>
#field n1 , Ptr <GtsGNode>
#field n2 , Ptr <GtsGNode>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSGRAPHCLASS>

#starttype GtsGraphClass
#field parent_class , <GtsHashContainerClass>
#field weight , FunPtr (Ptr <GtsGraph>  -> IO <gfloat>)
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSGRAPH>

#starttype GtsGraph
#field object , <GtsHashContainer>
#field graph_class , Ptr <GtsGraphClass>
#field node_class , Ptr <GtsGNodeClass>
#field edge_class , Ptr <GtsGEdgeClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSGRAPHTRAVERSE>

#opaque_t GtsGraphTraverse

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSTRAVERSETYPE>

#integral_t GtsTraverseType
#num GTS_BREADTH_FIRST

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSFNODE>

#starttype GtsFNode
#field node , <GtsGNode>
#field f , Ptr <GtsFace>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-graph-class.html#GTSFNODECLASS>

#starttype GtsFNodeClass
#field parent_class , <GtsGNodeClass>
#stoptype


-- | <http://gts.sourceforge.net/reference/gts-weighted-graph.html#GTSWGEDGECLASS>

#starttype GtsWGEdgeClass
#field parent_class , <GtsGEdgeClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-weighted-graph.html#GTSWGEDGE>

#starttype GtsWGEdge
#field gedge , <GtsGEdge>
#field weight , <gfloat>
#stoptype


-- | <http://gts.sourceforge.net/reference/gts-weighted-graph.html#GTSWGNODECLASS>

#starttype GtsWGNodeClass
#field parent_class , <GtsGNodeClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-weighted-graph.html#GTSWGNODE>

#starttype GtsWGNode
#field node , <GtsGNode>
#field weight , <gfloat>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-weighted-graph.html#GTSWGRAPHCLASS>

#starttype GtsWGraphClass
#field parent_class , <GtsGraphClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-weighted-graph.html#GTSWGRAPH>

#starttype GtsWGraph
#field graph , <GtsGraph>
#field weight , <gfloat>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-progressive-graph.html#GTSGNODESPLITCLASS>

#starttype GtsGNodeSplitClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-progressive-graph.html#GTSGNODESPLIT>

#starttype GtsGNodeSplit
#field object , <GtsObject>
#field n , Ptr <GtsGNode>
#field n1 , Ptr <GtsObject>
#field n2 , Ptr <GtsObject>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-progressive-graph.html#GTSPGRAPHCLASS>

#starttype GtsPGraphClass
#field parent_class , <GtsObjectClass>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-progressive-graph.html#GTSPGRAPH>

#starttype GtsPGraph
#field object , <GtsObject>
#field g , Ptr <GtsGraph>
#field split , Ptr <GPtrArray>
#field levels , Ptr <GArray>
#field split_class , Ptr <GtsGNodeSplitClass>
#field edge_class , Ptr <GtsWGEdgeClass>
#field pos , <guint>
#field min , <guint>
#field level , <guint>
#stoptype

-- | <http://gts.sourceforge.net/reference/gts-graph-partitioning.html#GTSGRAPHBISECTION>

#starttype GtsGraphBisection
#field g , Ptr <GtsGraph>
#field g1 , Ptr <GtsGraph>
#field g2 , Ptr <GtsGraph>
#field bg1 , Ptr <GHashTable>
#field bg2 , Ptr <GHashTable>
#stoptype

